==> jodd-all-4.2.0-sources.jar: jodd/madvoc/filter/ActionFilterStack.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.madvoc.filter;

import jodd.madvoc.ActionRequest;
import jodd.madvoc.BaseActionWrapperStack;

/**
 * Action filter stack.
 */
public class ActionFilterStack extends BaseActionWrapperStack<ActionFilter> implements ActionFilter {

	public ActionFilterStack() {
	}

	public ActionFilterStack(final Class<? extends ActionFilter>... filterClasses) {
		super(filterClasses);
	}

	/**
	 * Sets filter classes.
	 */
	public void setFilters(final Class<? extends ActionFilter>... filters) {
		this.wrappers = filters;
	}

	/**
	 * Returns an array of filters.
	 */
	public Class<? extends ActionFilter>[] getFilters() {
		return getWrappers();
	}


	/**
	 * Filter is not used since this is just an filter container.
	 */
	@Override
	public final Object filter(final ActionRequest actionRequest) throws Exception {
		return apply(actionRequest);
	}

}

==> jodd-all-4.3.2-sources.jar: jodd/madvoc/filter/ActionFilterStack.java <==
// Copyright (c) 2003-present, Jodd Team (http://jodd.org)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice,
// this list of conditions and the following disclaimer.
//
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
// LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

package jodd.madvoc.filter;

import jodd.madvoc.ActionRequest;
import jodd.madvoc.BaseActionWrapperStack;

/**
 * Action filter stack.
 */
public class ActionFilterStack extends BaseActionWrapperStack<ActionFilter> implements ActionFilter {

	public ActionFilterStack() {
	}

	public ActionFilterStack(final Class<? extends ActionFilter>... filterClasses) {
		super(filterClasses);
	}

	/**
	 * Sets filter classes.
	 */
	public void setFilters(final Class<? extends ActionFilter>... filters) {
		this.wrappers = filters;
	}

	/**
	 * Returns an array of filters.
	 */
	public Class<? extends ActionFilter>[] getFilters() {
		return getWrappers();
	}


	/**
	 * Filter is not used since this is just an filter container.
	 */
	@Override
	public final Object filter(final ActionRequest actionRequest) {
		return apply(actionRequest);
	}

}
